ModifierTypes

Enum ModifierTypes 

pub enum ModifierTypes {
Show 14 variants UnknownModifierType = 0, Static = 1, Public = 2, Protected = 3, Private = 4, Abstract = 5, Native = 6, Constructor = 7, Virtual = 8, Internal = 9, Final = 10, Readonly = 11, Module = 12, Lambda = 13,
}

Variants



UnknownModifierType = 0



Static = 1

The static modifier



Public = 2

The public modifier



Protected = 3

The protected modifier



Private = 4

The private modifier



Abstract = 5

The abstract modifier



Native = 6

The native modifier



Constructor = 7

The constructor modifier



Virtual = 8

The virtual modifier



Internal = 9

The internal modifier



Final = 10

The final modifier



Readonly = 11

The readonly modifier



Module = 12

Indicate that a method defines a module in the sense e.g. a python module does with the creation of a module object



Lambda = 13

Indicate that a method is an anonymous function, lambda, or closure